function c=filtrefourier(y)

% dtermination des coefficients de Fourier d'une fonction f chantillonne
%
% *********************************************************
%  c=filtrefourier(f) : dcomposition d'une fonction
%  f  valeurs dans C, priodique de priode T, connue sur [0,T] sous la forme 
% 
%  f(t)=sum_{i=nmin}^{nmax} c_n exp(2 i pi n t/T)
%  
%  avec nmin=-E((N-1)/2), nmax=E(N/2) 
% 
%  Cette fonction est connue via f_k=f(kT/N) o l appartient  {0,...,N-1}
%
%  * Variables d'entre : 
%     *  y : tableau contenant les complexes (y_k) pour k dans {0,...,N-1}
%  * Variables de sortie : 
%     *  c : tableau contenant les complexes (c_n) pour n dans {nmin,...,nmax}
%
%
% ************ Fonctions auxiliaires utilises ************
%
%    aucune
%
% *********************************************************
%
%  2007 by          Jrme BASTIEN
%                  Universit Claude Bernard Lyon I, UFRSTAPS, Laboratoire CRIS, Villeurbanne
%                  E-Mail : jerome.bastien@univ-lyon1.fr

% Attention au facteur N !!!
N=length(y);
if (N==0)
   error('N est nul : arrt du programme'); 
end
Y=(1/N)*fft(y);
nmin=-floor((N-1)/2);
nmax=floor(N/2);
c=zeros(1,N);
c(1:-nmin)=Y(nmax+2:end);
c(-nmin+1:end)=Y(1:nmax+1);