function [a,b]=filtrefourierre(y)

% dtermination des coefficients de Fourier d'une fonction f relle chantillonne
%
% *********************************************************
%  [a,b]=filtrefourierre(y) : dcomposition d'une fonction
%  f  valeurs dans R, priodique de priode T, connue sur [0,T] sous la forme 
% 
% si N est pair : 
%
%  f(t)=(1/2)*a_0+sum_{i=1}^{N/2-1}(a_n cos(2 pi n t/T)+b_n sin(2 pi n t/T))
%            +(1/2)*a_{N/2}(cos(pi N t/T)+i sin(pi N t/T))
% si N est impair : 
%
%  f(t)=1/2a_0+sum_{i=1}^{(N-1)/2}(a_n cos(2 pi n t/T)+b_n sin(2 pi n t/T))
%            +1/2*a_{N/2}(cos(pi N t/T)+i sin(pi N t/T))
% 
%  Cette fonction est connue via f_k=f(kT/N) o l appartient  {0,...,N-1}
%
%  * Variables d'entre : 
%     *  y : tableau contenant les complexes (y_k) pour k dans {0,...,N-1}
%  * Variables de sortie : 
%     *  a,b : tableaux contenant les rels :
%              a_0,...,a_{N/2} et b_1,...,b_{N/2-1} si N est pair
%              a_0,...,a_{(N-1)/2} et b_1,...,b_{(N-1)/2} si N est impair
%
%
% ************ Fonctions auxiliaires utilises ************
%
%    aucune
%
% *********************************************************
%
%  2007 by          Jrme BASTIEN
%                  Universit Claude Bernard Lyon I, UFRSTAPS, Laboratoire CRIS, Villeurbanne
%                  E-Mail : jerome.bastien@univ-lyon1.fr

% Attention au facteur N !!!
N=length(y);
if (N==0)
   error('N est nul : arrt du programme'); 
end
Y=(1/N)*fft(y);
nmax=floor(N/2);
a=zeros(1,nmax+1);
if (rem(N,2)==0)
    a([1,end])=2*Y([1,N/2+1]);
    a(2:end-1)=2*real(Y(2:N/2));
    b=-2*imag(Y(2:N/2));
else
    a(1)=2*Y(1);
    a(2:end)=2*real(Y(2:(N-1)/2+1));
    b=-2*imag(Y(2:(N-1)/2+1));
end