function y=recomfourier(c)

% Recomposition des valeurs temporelles  partir des coefficients de Fourier
%
% *********************************************************
%  y=recomfourier(c) : calcul des valeurs (y_k) pour k dans {0,...,N-1}
%  d'une fonction f  valeurs dans C, priodique de priode T, connue sur [0,T] sous la forme 
% 
%  f(t)=sum_{i=nmin}^{nmax} c_n exp(2 i pi n t/T)
%  
%  avec nmin=-E((N-1)/2), nmax=E(N/2) 
% 
%  * Variables d'entre : 
%     *  c : tableau contenant les complexes (c_n) pour n dans {nmin,...,nmax}
%  * Variables de sortie : 
%     *  y : tableau contenant les complexes (y_k) pour k dans {0,...,N-1}
%
%
% ************ Fonctions auxiliaires utilises ************
%
%    aucune
%
% *********************************************************
%
%  2007 by          Jrme BASTIEN
%                  Universit Claude Bernard Lyon I, UFRSTAPS, Laboratoire CRIS, Villeurbanne
%                  E-Mail : jerome.bastien@univ-lyon1.fr

N=length(c);
if (N==0)
   error('N est nul : arrt du programme'); 
end
nmin=-floor((N-1)/2);
nmax=floor(N/2);
Y=zeros(1,N);
Y(nmax+2:end)=c(1:-nmin);
Y(1:nmax+1)=c(-nmin+1:end);
% attention au facteur N !!!
y=N*ifft(Y);