function y=recomfourierre(a,b)

% Recomposition des valeurs temporelles  partir des coefficients de Fourier
%
% *********************************************************
%  y=recomfourierre(a,b) : calcul des valeurs (y_k) pour k dans {0,...,N-1}
%  d'une fonction f  valeurs dans R, priodique de priode T, connue sur [0,T] sous la forme 
% 
% si N est pair : 
%
%  f(t)=(1/2)*a_0+sum_{i=1}^{N/2-1}(a_n cos(2 pi n t/T)+b_n sin(2 pi n t/T))
%            +(1/2)*a_{N/2}(cos(pi N t/T)+i sin(pi N t/T))
% si N est impair : 
%
%  f(t)=1/2a_0+sum_{i=1}^{(N-1)/2}(a_n cos(2 pi n t/T)+b_n sin(2 pi n t/T))
%            +1/2*a_{N/2}(cos(pi N t/T)+i sin(pi N t/T))
% 
%  * Variables d'entre : 
%     *  a,b : tableaux contenant les rels :
%              a_0,...,a_{N/2} et b_1,...,b_{N/2-1} si N est pair
%              a_0,...,a_{(N-1)/2} et b_1,...,b_{(N-1)/2} si N est impair
%  * Variables de sortie : 
%     *  y : tableau contenant les complexes (y_k) pour k dans {0,...,N-1}
%
%
% ************ Fonctions auxiliaires utilises ************
%
%    aucune
%
% *********************************************************
%
%  2007 by          Jrme BASTIEN
%                  Universit Claude Bernard Lyon I, UFRSTAPS, Laboratoire CRIS, Villeurbanne
%                  E-Mail : jerome.bastien@univ-lyon1.fr

nmax=length(a)-1;
if ((length(a)-length(b))==2)
    N=2*nmax;
else
    N=2*nmax+1;
end
if (N==0)
   error('N est nul : arrt du programme'); 
end
Y=zeros(1,N);
if (N==1)
    y=a/2;
else
    if ((length(a)-length(b))==2)
        Y([1,nmax+1])=(a([1,nmax+1]))/2;
        Y(2:nmax)=(a(2:nmax)-i*b)/2;
        Y(nmax+2:N)=(fliplr(a(2:end-1))+i*fliplr(b))/2;
    else
        Y(1)=(a(1))/2;
        Y(2:nmax+1)=(a(2:end)-i*b)/2;
        Y(nmax+2:N)=(fliplr(a(2:end))+i*fliplr(b))/2;
    end
    % attention au facteur N !!!
    y=N*ifft(Y);
    if (~isreal(y))
       y=real(y); 
    end
end