function [dXa,dYa,dna,ddXa,ddYa,ddna]=calculapproch_vi_acc(CX,CY,fe)

% calcul des vitesses et des acclrations approches d'un kinogramme
%
% *********************************************************
%  [dXa,dYa,dna,ddXa,ddYa,ddna]=calculapproch_vi_acc(CX,CY,fe) : 
%
%  * Variables d'entre : 
%     *  CX :  tableau de type (n+1,p) o pour tout i dans {0,...,n}, 
%                                         pour tout j dans {1,...,p},
%              CX(i+1,j) est l'abscisse de A_j  l'instant t_i=i/fe
%     *  CY :  tableau de type (n+1,p) o pour tout i dans {0,...,n}, 
%                                         pour tout j dans {1,...,p},
%              CY(i+1,j) est l'ordonne de A_j  l'instant t_i=i/fe
%    *  fe : frquence d'acquisition
%  * Variables de sortie : 
%     *  dXa :  tableau de type (n,p) o pour tout i dans {0,...,n}, 
%                                        pour tout j dans {1,...,p},
%               dXa(i,j) est l'abscisse de la vitesse aproche de A_j  l'instant
%                         (t_i+t_{i+1})/2
%     *  dYa :  tableau de type (n,p) o pour tout i dans {0,...,n}, 
%                                        pour tout j dans {1,...,p},
%               dXa(i,j) est l'ordonne de la vitesse aproche de A_j  l'instant
%                         (t_i+t_{i+1})/2
%     *  dna :  tableau de type (n,p) o pour tout i dans {0,...,n}, 
%                                        pour tout j dans {1,...,p},
%               dna(i,j) est la norme de la vitesse aproche de A_j  l'instant
%                         (t_i+t_{i+1})/2
%     *  ddXa :  tableau de type (n-1,p) o pour tout i dans {1,...,n-1}, 
%                                        pour tout j dans {1,...,p},
%               ddXa(i,j) est l'abscisse de l'acclration aproche de A_j  l'instant t_i
%     *  ddYa :  tableau de type (n-1,p) o pour tout i dans {1,...,n-1}, 
%                                        pour tout j dans {1,...,p},
%               ddYa(i,j) est l'ordonne de l'acclration aproche de A_j  l'instant t_i
%     *  ddna :  tableau de type (n-1,p) o pour tout i dans {1,...,n-1}, 
%                                        pour tout j dans {1,...,p},
%               ddna(i,j) est la norme de l'acclration aproche de A_j  l'instant t_i
%
%
%
%
% ************ Fonctions auxiliaires utilises ************
%
%    aucune
%
% *********************************************************
%
% 2007 by          Jrme BASTIEN
%                  Universit Claude Bernard Lyon I, UFRSTAPS, Laboratoire CRIS, Villeurbanne
%                  E-Mail : jerome.bastien@univ-lyon1.fr


dXa=(diff(CX))*fe;
dYa=(diff(CY))*fe;
dna=sqrt(dXa.^2+dYa.^2);
ddXa=(CX(1:end-2,:)-2*CX(2:end-1,:)+CX(3:end,:))*(fe^2);
ddYa=(CY(1:end-2,:)-2*CY(2:end-1,:)+CY(3:end,:))*(fe^2);
ddna=sqrt(ddXa.^2+ddYa.^2);
