function [dtheta,ddtheta]=calculapproch_vi_acc_ang(theta,fe)

% calcul des vitesses et des acclrations angulaires approches
%
% *********************************************************
%  [dtheta,ddtheta]=calculapproch_vi_acc_ang(theta,fe) : 
%
%  * Variables d'entre : 
%     * theta : tableau de type (n+1,p-1) o pour tout i dans {0,...,n}, 
%                                         pour tout j dans {1,...,p-1},
%              theta(i+1,j) est l'angle articulaire (A{j-1}_A_{j},A{j}_A_{j+1})
%               l'instant t_i=i/fe
%    *  fe : frquence d'acquisition
%  * Variables de sortie : 
%     * dtheta : tableau de type (n,p-1) o pour tout i dans {0,...,n}, 
%                                         pour tout j dans {1,...,p-1},
%              dtheta(i+1,j) est la vitesse approche de l'angle articulaire (A{j-1}_A_{j},A{j}_A_{j+1})
%               l'instant t_i+t_{i+1})/2
%     * ddtheta : tableau de type (n-1,p-1) o pour tout i dans {1,...,n-1}, 
%                                         pour tout j dans {1,...,p-1},
%              dtheta(i+1,j) est l'accalration aproche de l'angle articulaire (A{j-1}_A_{j},A{j}_A_{j+1})
%               l'instant t_i
%
%
%
%
% ************ Fonctions auxiliaires utilises ************
%
%    aucune
%
% *********************************************************
%
% 2007 by          Jrme BASTIEN
%                  Universit Claude Bernard Lyon I, UFRSTAPS, Laboratoire CRIS, Villeurbanne
%                  E-Mail : jerome.bastien@univ-lyon1.fr


dtheta=(diff(theta))*fe;
ddtheta=(theta(1:end-2,:)-2*theta(2:end-1,:)+theta(3:end,:))*(fe^2);
