function [l,theta,dis]=long_angle(CX,CY)

% Dtermination des angles articulaires et des longueurs 
%
% *********************************************************
%  [l,theta,dis]=long_angle(CX,CY) : 
%
%  * Variables d'entres : donnes du kinogrammes  la frquence d'acquisition fe
%     *  CX :  tableau de type (n+1,p) o pour tout i dans {0,...,n}, 
%                                         pour tout j dans {1,...,p},
%              CX(i+1,j) est l'abscisse de A_j  l'instant t_i=i/fe
%     *  CY :  tableau de type (n+1,p) o pour tout i dans {0,...,n}, 
%                                         pour tout j dans {1,...,p},
%              CY(i+1,j) est l'ordonne de A_j  l'instant t_i=i/fe
%  * Variables de sortie :
%     *  l :  tableau de type (1,p-1) reprsentant les longueurs 
%             moyennes en temps
%     * theta : tableau de type (n+1,p-1) o pour tout i dans {0,...,n}, 
%                                         pour tout j dans {1,...,p-1},
%              theta(i+1,j) est l'angle articulaire (A{j-1}_A_{j},A{j}_A_{j+1})
%               l'instant t_i=i/fe
%              Attention, initialement dans ]-pi,pi], modulo 2pi, ces angles
%              ont t traits temporellement par la fonction unwrap
%              pour viter leurs discontinits.
%     *  dis :  tableau de type (1,p-1) reprsentant les dispersion des longueurs 
%              (dviation standart/moyenne)
%
%
% ************ Fonctions auxiliaires utilises ************
%
%    modulo2pi
%
% *********************************************************
%
% 2007 by          Jrme BASTIEN
%                  Universit Claude Bernard Lyon I, UFRSTAPS, Laboratoire CRIS, Villeurbanne
%                  E-Mail : jerome.bastien@univ-lyon1.fr

[jr,q]=size(CX.');
j=jr-1;
if (jr==0)
   error('ATTENTION : pas de point !'); 
end
if (q==0)
   error('ATTENTION : pas de temps !'); 
end
theta=zeros(j,q);
l=zeros(j,q);
if (j~=0)
    phict=zeros(j,q);
    auxix=diff(CX.');
    auxiy=diff(CY.');
    [phict,l]=cart2pol(auxix,auxiy);
    theta(1,:)=modulo2pi(phict(1,:));
    if (j>=2)
        theta(2:j,:)=modulo2pi(diff(phict));
    end
end
l=l.';
theta=theta.';
theta=unwrap(theta);
lm=(mean(l));
dis=(std(l))./lm;
l=lm;