function [Xn,Yn]=reconst_angle(l,theta,Xorg,Yorg)

% Dtermination des coordonnes  d'un kinogramme  partir des angles articulaires
%
% *********************************************************
%  [Xn,Yn]=reconst_angle(l,theta,Xorg,Yorg) : 
%
%	* Variables d'entres :
%     *  l :  tableau de type (1,p-1) reprsentant les longueurs 
%     * theta : tableau de type (n+1,p-1) o pour tout i dans {0,...,n}, 
%                                         pour tout j dans {1,...,p-1},
%              theta(i+1,j) est l'angle articulaire (A{j-1}_A_{j},A{j}_A_{j+1})
%               l'instant t_i=i/fe (fe : frquence d'acquisition)
%     * Xorg : tableau de taille (n+1,1) o 
%              o pour tout i dans {0,...,n}, 
%              Xorg(i+1) est l'abscisse de A_1  l'instant t_i=i/fe
%     * Yorg : tableau de taille (n+1,1) o 
%              o pour tout i dans {0,...,n}, 
%              Xorg(i+1) est l'ordonne de A_1  l'instant t_i=i/fe
%  * Variables de sortie :
%     *  Xn :  tableau de type (n+1,p) o pour tout i dans {0,...,n}, 
%                                         pour tout j dans {1,...,p},
%              Xn(i+1,j) est l'abscisse de A_j  l'instant t_i=i/fe
%     *  Yn :  tableau de type (n+1,p) o pour tout i dans {0,...,n}, 
%                                         pour tout j dans {1,...,p},
%              Yn(i+1,j) est l'ordonne de A_j  l'instant t_i=i/fe
%
%
% ************ Fonctions auxiliaires utilises ************
%
%     cumsumsym2 (pour des calculs symboliques uniquement)
%
% *********************************************************
%
% 2007 by          Jrme BASTIEN
%                  Universit Claude Bernard Lyon I, UFRSTAPS, Laboratoire CRIS, Villeurbanne
%                  E-Mail : jerome.bastien@univ-lyon1.fr

jr=length(l);
[q,j]=size(theta);
if (q==0)
   error('ATTENTION : pas de temps !'); 
end
if (j~=jr)
   error('Les deux tableaux n''ont pas la taille adquate'); 
end
resX=zeros(j+1,q);
resY=zeros(j+1,q);
if (j~=0)
    if (isnumeric(theta))
        auxitheta=cumsum(theta,2);
        resX=(cumsum(cos(auxitheta).*(ones(q,1)*l),2)).';
        resY=(cumsum(sin(auxitheta).*(ones(q,1)*l),2)).';
    else
        auxitheta=cumsumsym2(theta);
        resX=(cumsumsym2(cos(auxitheta).*(ones(q,1)*l))).';
        resY=(cumsumsym2(sin(auxitheta).*(ones(q,1)*l))).';

    end
    resX=[zeros(1,q);resX];
    resY=[zeros(1,q);resY];
end
Xn=resX.'+Xorg(:,ones(1,j+1));
Yn=resY.'+Yorg(:,ones(1,j+1));