function tracecoordvitacc(fe,CX,CY,dXa,dYa,dna,ddXa,ddYa,ddna,nomfic,nomeps)

% affichage des coordonnes, vitesse (approches) et acclrations (approches )
% au cours du temps
%
% *********************************************************
% tracecoordvitacc(fe,CX,CY,dXa,dYa,dna,ddXa,ddYa,ddna,nomfic,nomeps) : 
%
%  * Variables d'entre :
%     *  fe : frquence d'acquisition
%     *  CX :  tableau de type (n+1,p) o pour tout i dans {0,...,n}, 
%                                         pour tout j dans {1,...,p},
%              CX(i+1,j) est l'abscisse de A_j  l'instant t_i=i/fe
%     *  CY :  tableau de type (n+1,p) o pour tout i dans {0,...,n}, 
%                                         pour tout j dans {1,...,p},
%              CY(i+1,j) est l'ordonne de A_j  l'instant t_i=i/fe
%     *  dXa :  tableau de type (n,p) o pour tout i dans {0,...,n}, 
%                                        pour tout j dans {1,...,p},
%               dXa(i,j) est l'abscisse de la vitesse aproche de A_j  l'instant
%                         (t_i+t_{i+1})/2
%     *  dYa :  tableau de type (n,p) o pour tout i dans {0,...,n}, 
%                                        pour tout j dans {1,...,p},
%               dXa(i,j) est l'ordonne de la vitesse aproche de A_j  l'instant
%                         (t_i+t_{i+1})/2
%     *  dna :  tableau de type (n,p) o pour tout i dans {0,...,n}, 
%                                        pour tout j dans {1,...,p},
%               dna(i,j) est la norme de la vitesse aproche de A_j  l'instant
%                         (t_i+t_{i+1})/2
%     *  ddXa :  tableau de type (n-1,p) o pour tout i dans {1,...,n-1}, 
%                                        pour tout j dans {1,...,p},
%               ddXa(i,j) est l'abscisse de l'acclration aproche de A_j  l'instant t_i
%     *  ddYa :  tableau de type (n-1,p) o pour tout i dans {1,...,n-1}, 
%                                        pour tout j dans {1,...,p},
%               ddYa(i,j) est l'ordonne de l'acclration aproche de A_j  l'instant t_i
%     *  ddna :  tableau de type (n-1,p) o pour tout i dans {1,...,n-1}, 
%                                        pour tout j dans {1,...,p},
%               ddna(i,j) est la norme de l'acclration aproche de A_j  l'instant t_i
%
%  * Variables d'entre facultative (dans l'ordre)
%     *  nomfic : nom du fichier texte sans l'extension txt (pour le titre)
%     *  nomeps : nom du fichier de stockage de la figure eps (sans
%                    extension eps)
%
%
% ************ Fonctions auxiliaires utilises ************
%
%    aucune
%
% *********************************************************
%
% (c) 2007 by      Jrme BASTIEN 
%                  Universit Lyon I, Laboratoire CRIS, Villeurbanne
%                  E-Mail : jerome.bastien@utbm.fr

legne=[''];
[np,p]=size(CX);
for k=1:p-1
   legne=[legne,'''',int2str(k),'''',','];
end
legne=[legne,'''',int2str(p),''''];
temps=(0:np-1)/fe;
tempsvit=temps(1:end-1)+1/(2*fe);
tempsacc=temps(2:end-1);
clf;
subplot(3,1,1)
hold on;
plot(temps,CX);
if nargin>=10
    title(['abscisse de ',nomfic]);
end
dud=version;
if (str2num(dud(1))>=7)
    eval(['legend(',legne,',''location'',''best'')']);
else
    eval(['legend(',legne,',0)']);
end  
hold off;
subplot(3,1,2)
hold on;
plot(tempsvit,dXa);
if nargin>=10
    title(['abscisse de la vitesse approche de ',nomfic]);
end
if (str2num(dud(1))>=7)
    eval(['legend(',legne,',''location'',''best'')']);
else
    eval(['legend(',legne,',0)']);
end  
hold off;
subplot(3,1,3)
hold on;
plot(tempsacc,ddXa);
if nargin>=10
    title(['abscisse de l''acclration de approche de ',nomfic]);
end
if (str2num(dud(1))>=7)
    eval(['legend(',legne,',''location'',''best'')']);
else
    eval(['legend(',legne,',0)']);
end  
hold off;
if nargin==11
   eval(['print -depsc ',nomeps,'abs.eps;']); 
end
disp('Appuyez sur une touche pour continuer');
pause;
clf;
subplot(3,1,1)
hold on;
plot(temps,CY);
if nargin>=10
    title(['ordonne de ',nomfic]);
end
if (str2num(dud(1))>=7)
    eval(['legend(',legne,',''location'',''best'')']);
else
    eval(['legend(',legne,',0)']);
end  
hold off;
subplot(3,1,2)
hold on;
plot(tempsvit,dYa);
if nargin>=10
    title(['ordonne de la vitesse approche de ',nomfic]);
end
if (str2num(dud(1))>=7)
    eval(['legend(',legne,',''location'',''best'')']);
else
    eval(['legend(',legne,',0)']);
end  
hold off;
subplot(3,1,3)
hold on;
plot(tempsacc,ddYa);
if nargin>=10
    title(['ordonne de l''acclration de approche de ',nomfic]);
end
if (str2num(dud(1))>=7)
    eval(['legend(',legne,',''location'',''best'')']);
else
    eval(['legend(',legne,',0)']);
end  
hold off;
if nargin==11
   eval(['print -depsc ',nomeps,'ord.eps;']); 
end
disp('Appuyez sur une touche pour continuer');
pause;
clf;
subplot(2,1,1)
hold on;
plot(tempsvit,dna);
if nargin>=10
    title(['norme de la vitesse approche de ',nomfic]);
end
if (str2num(dud(1))>=7)
    eval(['legend(',legne,',''location'',''best'')']);
else
    eval(['legend(',legne,',0)']);
end  
hold off;
subplot(2,1,2)
hold on;
plot(tempsacc,ddna);
if nargin>=10
    title(['norme de l''accration approche de ',nomfic]);
end
if (str2num(dud(1))>=7)
    eval(['legend(',legne,',''location'',''best'')']);
else
    eval(['legend(',legne,',0)']);
end  
hold off;
if nargin==11
   eval(['print -depsc ',nomeps,'norm.eps;']); 
end
