function tracekinogramme(CX,CY,tracart,nomfic,nomavi,feavi,nomeps)

% trac du kinogramme
%
% *********************************************************
%  tracekinogramme(CX,CY,tracart,nomfic,nomeps) : 
%  trace 
%  * le kinogramme en bleu
%  * ventuellement les trajectoires des articulations en rouge 
%  * les positions des articulations avec un rond rouge
%
%  * Variables d'entre : 
%     *  CX :  tableau de type (n+1,p) o pour tout i dans {0,...,n}, 
%                                         pour tout j dans {1,...,p},
%              CX(i+1,j) est l'abscisse de A_j  l'instant t_i=i/fe
%     *  CY :  tableau de type (n+1,p) o pour tout i dans {0,...,n}, 
%                                         pour tout j dans {1,...,p},
%              CY(i+1,j) est l'ordonne de A_j  l'instant t_i=i/fe
%    *   tracart : entier gal  0 (pas de trac des trajectoires des articulation) ou 1 (trac) 
%  * Variables d'entre facultative (dans l'ordre)
%     *  nomfic : nom du fichier texte sans l'extension txt (pour le titre)
%     *  nomavi : nom du fichier de stockage de l'animation avi (sans
%                    extension)
%     *  fevai : frquence du nombre d'image pour l'animation avi
%     *  nomeps : nom du fichier de stockage de la figure eps (sans
%                    extension eps)
%
%
% ************ Fonctions auxiliaires utilises ************
%
%    aucune
%
% *********************************************************
%
% 2007 by          Jrme BASTIEN
%                  Universit Claude Bernard Lyon I, UFRSTAPS, Laboratoire CRIS, Villeurbanne
%                  E-Mail : jerome.bastien@univ-lyon1.fr



clf;
hold on;
axis equal;
if (tracart)
   plot(CX,CY,'r');
end
plot(CX',CY','b');
plot(CX,CY,'or');
if nargin>=5
   h=gca;
   xlimm=get(h,'XLim');
   ylimm=get(h,'YLim');
end
hold off;
if nargin>=5
    [kk,noubli]=size(CX);
    mov=avifile([nomavi,'.avi'],'quality',100,'fps',feavi);
    for jj=1:kk
        hold on;
        clf;
        plot(CX(jj,:),CY(jj,:),'b',CX(jj,:),CY(jj,:),'or');
        xlim(xlimm);
        ylim(ylimm);
        hold off;
        Fanimbis=getframe;
        mov=addframe(mov,Fanimbis);
    end
    mov=close(mov);
end
clf;
hold on;
axis equal;
if (tracart)
   plot(CX,CY,'r');
end
plot(CX',CY','b');
plot(CX,CY,'or');
if nargin>=4
    title(['kinogramme de ',nomfic]);
end
if nargin==7
   eval(['print -depsc ',nomeps,'.eps;']); 
end
if nargin>=5
   h=gca;
   xlimm=get(h,'XLim');
   ylimm=get(h,'YLim');
end
hold off;
