function  [fe,CX,CY,dXa,dYa,dna,ddXa,ddYa,ddna,l,theta,dis,dtheta,ddtheta,ecXY]=...  
          traitekinogramme(nomfic,tracart,alphaavit,indvit,alphaaacc,...
          indacc,nomavi,fevai,nomepskino,nomepsvit,nomepsacc,nomtemps,nomangle)

% lecture du fichier de donnes d'un kinogramme et traitement brut des coordonnes
%
% *********************************************************
% [fe,CX,CY,l,theta,dis,dtheta,ddtheta,ecXY,dXa,dYa,dna,ddXa,ddYa,ddna]=...  
%          traitekinogramme(nomfic,tracart,alphaavit,indvit,alphaaacc,...
%          indacc,nomavi,fevai,nomepskino,nomepsvit,nomepsacc,nomtemps,nomangle) : 
% Lit le fichier de donnes texte (de type donneeskinogtapoint.txt) et 
% - affiche les donnes spatiales et temporelles (dplacements, vitesses et acclration)
% - enregistre une animation si nomavi
% - stocke les fichiers eps si les noms correspondant sont prsents.
%
%  Variables d'entres : 
%    *   nomfic : nom du fichier texte sans l'extension txt
%    *   tracart : entier gal  0 (pas de trac des trajectoires des articulation) ou 1 (trac) 
%    *   alphaavit : coefficient d'chelle pour la vitesse
%    *   indvit=indice d'articulation dont la vitesse n'est pas en pointill
%        si vide, toutes identiques
%    *   alphaaacc : coefficient d'chelle pour l'acclration
%    *   indacc=indice d'articulation dont l'acclration n'est pas en pointill
%        si vide, toutes identiques
%  Variables d'entres optionneelles (dans l'ordre)
%     *  nomavi : nom du fichier de stockage de l'animation avi (sans
%                    extension)
%     *  fevai : frquence du nombre d'image pour l'animation avi
%     *  nomepskino : nom du fichier de stockage de la figure eps (sans
%                    extension eps) pour le kinogramme
%     *  nomepsvit : nom du fichier de stockage de la figure eps (sans
%                    extension eps) pour les vitesses (espace)
%     *  nomepsacc : nom du fichier de stockage de la figure eps (sans
%                    extension eps) pour les acclration (espace)
%     *  nomtemps : nom du fichier de stockage de la figure eps (sans
%                    extension eps) pour les donnes temporelles 
%     *  nomangle : nom du fichier de stockage de la figure eps (sans
%                    extension eps) pour les angles
%
%  Variables de sortie :
%     *  fe : frquence d'acquisition
%     *  CX :  tableau de type (n+1,p) o pour tout i dans {0,...,n}, 
%                                         pour tout j dans {1,...,p},
%              CX(i+1,j) est l'abscisse de A_j  l'instant t_i=i/fe
%     *  CY :  tableau de type (n+1,p) o pour tout i dans {0,...,n}, 
%                                         pour tout j dans {1,...,p},
%              CY(i+1,j) est l'ordonne de A_j  l'instant t_i=i/fe
%     *  dXa :  tableau de type (n,p) o pour tout i dans {0,...,n}, 
%                                        pour tout j dans {1,...,p},
%               dXa(i,j) est l'abscisse de la vitesse aproche de A_j  l'instant
%                         (t_i+t_{i+1})/2
%     *  dYa :  tableau de type (n,p) o pour tout i dans {0,...,n}, 
%                                        pour tout j dans {1,...,p},
%               dXa(i,j) est l'ordonne de la vitesse aproche de A_j  l'instant
%                         (t_i+t_{i+1})/2
%     *  dna :  tableau de type (n,p) o pour tout i dans {0,...,n}, 
%                                        pour tout j dans {1,...,p},
%               dna(i,j) est la norme de la vitesse aproche de A_j  l'instant
%                         (t_i+t_{i+1})/2
%     *  ddXa :  tableau de type (n-1,p) o pour tout i dans {1,...,n-1}, 
%                                        pour tout j dans {1,...,p},
%               ddXa(i,j) est l'abscisse de l'acclration aproche de A_j  l'instant t_i
%     *  ddYa :  tableau de type (n-1,p) o pour tout i dans {1,...,n-1}, 
%                                        pour tout j dans {1,...,p},
%               ddYa(i,j) est l'ordonne de l'acclration aproche de A_j  l'instant t_i
%     *  ddna :  tableau de type (n-1,p) o pour tout i dans {1,...,n-1}, 
%                                        pour tout j dans {1,...,p},
%               ddna(i,j) est la norme de l'acclration aproche de A_j  l'instant t_i
%  Variables de sortie optionnelles :
%     *  l :  tableau de type (1,p-1) reprsentant les longueurs 
%             moyennes en temps
%     * theta : tableau de type (n+1,p-1) o pour tout i dans {0,...,n}, 
%                                         pour tout j dans {1,...,p-1},
%              theta(i+1,j) est l'angle articulaire (A{j-1}_A_{j},A{j}_A_{j+1})
%               l'instant t_i=i/fe
%     * dis :  tableau de type (1,p-1) reprsentant les dispersion des longueurs 
%              (dviation standart/moyenne)
%     * dtheta : tableau de type (n,p-1) o pour tout i dans {0,...,n}, 
%                                         pour tout j dans {1,...,p-1},
%              dtheta(i+1,j) est la vitesse approche de l'angle articulaire (A{j-1}_A_{j},A{j}_A_{j+1})
%               l'instant t_i+t_{i+1})/2
%     * ddtheta : tableau de type (n-1,p-1) o pour tout i dans {1,...,n-1}, 
%                                         pour tout j dans {1,...,p-1},
%              dtheta(i+1,j) est l'accalration aproche de l'angle articulaire (A{j-1}_A_{j},A{j}_A_{j+1})
%               l'instant t_i
%     * ecXY : cart maximum entre les X, Y et les X et Y reconstitus  partir des angles
%
%
% ************ Fonctions auxiliaires utilises ************
%
%    litfichierdonneskino
%    long_angle
%    calculapproch_vi_acc_ang
%    reconst_angle
%    calculapproch_vi_acc
%    tracekinogramme
%    tracekinovitkino
%    tracekinoacckino
%    tracecoordvitacc
%    tracecoordvitacc_ang
%
% *********************************************************
%
% 2007 by          Jrme BASTIEN
%                  Universit Claude Bernard Lyon I, UFRSTAPS, Laboratoire CRIS, Villeurbanne
%                  E-Mail : jerome.bastien@univ-lyon1.fr

[CX,CY,fe]=litfichierdonneskino(nomfic);
nout=nargout;
if (nout==15)
    [l,theta,dis]=long_angle(CX,CY);
    [dtheta,ddtheta]=calculapproch_vi_acc_ang(theta,fe);
    [Xn,Yn]=reconst_angle(l,theta,CX(:,1),CY(:,1));
    ecXY=max([max(max(abs(CX-Xn))),max(max(abs(CY-Yn)))]);
    CX=Xn;
    CY=Yn;
end
[dXa,dYa,dna,ddXa,ddYa,ddna]=calculapproch_vi_acc(CX,CY,fe);
switch nargin
    case 6 
        tracekinogramme(CX,CY,tracart,nomfic);    
    case 8 
        tracekinogramme(CX,CY,tracart,nomfic,nomavi,fevai);
    otherwise
        tracekinogramme(CX,CY,tracart,nomfic,nomavi,fevai,nomepskino);
end
disp('Appuyez sur une touche pour continuer');
pause;
if nargin>=10
    tracekinovitkino(CX,CY,dXa,dYa,tracart,alphaavit,indvit,nomfic,nomepsvit);
else    
    tracekinovitkino(CX,CY,dXa,dYa,tracart,alphaavit,indvit,nomfic);
end
disp('Appuyez sur une touche pour continuer');
pause;
if nargin>=11
    tracekinoacckino(CX,CY,ddXa,ddYa,tracart,alphaaacc,indacc,nomfic,nomepsacc);
else    
    tracekinoacckino(CX,CY,ddXa,ddYa,tracart,alphaaacc,indacc,nomfic);
end
disp('Appuyez sur une touche pour continuer');
pause;
if nargin>=12
    tracecoordvitacc(fe,CX,CY,dXa,dYa,dna,ddXa,ddYa,ddna,nomfic,nomtemps);
else    
    tracecoordvitacc(fe,CX,CY,dXa,dYa,dna,ddXa,ddYa,ddna,nomfic);
end
if (nout==15)
    disp('Appuyez sur une touche pour continuer');
    pause;
    if nargin>=13
        tracecoordvitacc_ang(fe,theta,dtheta,ddtheta,nomfic,nomangle);
    else
        tracecoordvitacc_ang(fe,theta,dtheta,ddtheta,nomfic);
    end    
end
    
