function [CXn,CYn,dXa,dYa,dna,ddXa,ddYa,ddna]=enrichissementkino(CX,CY,fe,meth,q)

% enrichissement et calcul des vitesses et des acclrations approches d'un kinogramme
%
% *********************************************************
%  [CXn,CYn,dXa,dYa,dna,ddXa,ddYa,ddna]=enrichissementkino(CX,CY,fe,meth,q) :  
%
%  * Variables d'entre : 
%     *  CX :  tableau de type (n+1,p) o pour tout i dans {0,...,n}, 
%                                         pour tout j dans {1,...,p},
%              CX(i+1,j) est l'abscisse de A_j  l'instant t_i=i/fe
%     *  CY :  tableau de type (n+1,p) o pour tout i dans {0,...,n}, 
%                                         pour tout j dans {1,...,p},
%              CY(i+1,j) est l'ordonne de A_j  l'instant t_i=i/fe
%    *  fe : frquence d'acquisition
%    CES TROIS DONNEES CORRESPONDENT AU KINOGRAMME INITIAL
%    * meth : chane de caractre indiquant la mthode choisie
%           * 'i' : interpolation polynmiale
%           * 's' : interpolation par spline cubique (spline)
%           * 'p' : interpolation par Hermite cubique (pchip)
%    * q : entier suprieur  un gal au rapport frquence enrichie/frquence initiale
%  * Variables de sortie : 
%    CES DONNEES CORRESPONDENT AU KINOGRAMME ENRICHI
%     *  CXn :  tableau de type (nr+1,p) o pour tout i dans {0,...,nr}, 
%                                          pour tout j dans {1,...,p},
%              CX(i+1,j) est l'abscisse de A_j  l'instant t_i=i/fer
%     *  CYn :  tableau de type (nr+1,p) o pour tout i dans {0,...,nr}, 
%                                          pour tout j dans {1,...,p},
%              CY(i+1,j) est l'ordonne de A_j  l'instant t_i=i/fer
%     *  dXa :  tableau de type (nr+1,p) o pour tout i dans {0,...,nr}, 
%                                           pour tout j dans {1,...,p},
%               dXa(i+1,j) est l'abscisse de la vitesse approche de A_j  l'instant
%               t_i=i/fer
%     *  dYa :  tableau de type (nr+1,p) o pour tout i dans {0,...,nr}, 
%                                           pour tout j dans {1,...,p},
%               dXa(i+1,j) est l'ordonne de la vitesse approche de A_j  l'instant
%               t_i=i/fer
%     *  dna :  tableau de type (nr+1,p) o pour tout i dans {0,...,nr}, 
%                                           pour tout j dans {1,...,p},
%               dna(i+1,j) est la norme de la vitesse approche de A_j  l'instant
%               t_i=i/fer
%     *  ddXa :  tableau de type (nr+1,p) o pour tout i dans {0,...,nr}, 
%                                           pour tout j dans {1,...,p},
%               dXa(i+1,j) est l'abscisse de l'acclration approche de A_j  l'instant
%               t_i=i/fer
%     *  ddYa :  tableau de type (nr+1,p) o pour tout i dans {0,...,nr}, 
%                                           pour tout j dans {1,...,p},
%               dXa(i+1,j) est l'ordonne de l'acclration approche de A_j  l'instant
%               t_i=i/fer
%     *  ddna :  tableau de type (nr+1,p) o pour tout i dans {0,...,nr}, 
%                                           pour tout j dans {1,...,p},
%               dna(i+1,j) est la norme de l'acclration approche de A_j  l'instant
%               t_i=i/fer
%
%
%
% ************ Fonctions auxiliaires utilises ************
%
%    ATTENTION : utilise la fonction fnder de la toobox matlab 
%    splines (C:\MATLAB6p1\toolbox\splines).
%    fnder.m n'est pas prsente dans la version 7 de matlab.
%    La fonction fnder.m est stocke dans ce rpertoire
%    et renomme OLDfnder.m 
%    A TESTER SOUS LES VERSIONS ULTERIEURES DE MATLAB.
%
% *********************************************************
%
% 2007 by          Jrme BASTIEN
%                  Universit Claude Bernard Lyon I, UFRSTAPS, Laboratoire CRIS, Villeurbanne
%                  E-Mail : jerome.bastien@univ-lyon1.fr


[np,p]=size(CX);
n=np-1;
temps=(0:n)/fe;
tempsn=(0:q*n)/(q*fe);
CXn=zeros(q*n+1,p);
CYn=zeros(q*n+1,p);
dXa=zeros(q*n+1,p);
dYa=zeros(q*n+1,p);
ddXa=zeros(q*n+1,p);
ddYa=zeros(q*n+1,p);
for j=1:p
    switch meth
        case 'i'
            DX=diff_div_dist(temps,CX(:,j));
            DY=diff_div_dist(temps,CY(:,j));
            [Zx,Zpx,Zppx]=eval_hornerder(tempsn,temps(1:end-1),DX);
            [Zy,Zpy,Zppy]=eval_hornerder(tempsn,temps(1:end-1),DY);
            CXn(:,j)=Zx.';
            CYn(:,j)=Zy.';
            dXa(:,j)=Zpx.';
            dYa(:,j)=Zpy.';
            ddXa(:,j)=Zppx.';
            ddYa(:,j)=Zppy.';
        case 's'
            ppX0=spline(temps,CX(:,j));
            ppY0=spline(temps,CY(:,j));
            for kk=1:2
                eval(['ppX',int2str(kk),'=','OLDfnder(ppX',int2str(kk-1),');']);    
                eval(['ppY',int2str(kk),'=','OLDfnder(ppY',int2str(kk-1),');']);    
            end
            CXn(:,j)=(ppval(ppX0,tempsn)).';
            CYn(:,j)=(ppval(ppY0,tempsn)).';
            dXa(:,j)=(ppval(ppX1,tempsn)).';
            dYa(:,j)=(ppval(ppY1,tempsn)).';
            ddXa(:,j)=(ppval(ppX2,tempsn)).';
            ddYa(:,j)=(ppval(ppY2,tempsn)).';
        case 'p'
            ppX0=pchip(temps,CX(:,j));
            ppY0=pchip(temps,CY(:,j));
            for kk=1:2
                eval(['ppX',int2str(kk),'=','OLDfnder(ppX',int2str(kk-1),');']);    
                eval(['ppY',int2str(kk),'=','OLDfnder(ppY',int2str(kk-1),');']);    
            end
            CXn(:,j)=(ppval(ppX0,tempsn)).';
            CYn(:,j)=(ppval(ppY0,tempsn)).';
            dXa(:,j)=(ppval(ppX1,tempsn)).';
            dYa(:,j)=(ppval(ppY1,tempsn)).';
            ddXa(:,j)=(ppval(ppX2,tempsn)).';
            ddYa(:,j)=(ppval(ppY2,tempsn)).';
    end
end
dna=sqrt(dXa.^2+dYa.^2);
ddna=sqrt(ddXa.^2+ddYa.^2);