function [thetan,dthetan,ddthetan]=enrichissementkino_angl(theta,fe,meth,q)

% enrichissement et calcul des vitesses et des acclrations approches des angles theta d'un kinogramme
%
% *********************************************************
%  [dtheta,ddtheta]=enrichissementkino_angl(theta,fe,meth,q) :  
%
%  * Variables d'entre : 
%     * theta : tableau de type (n+1,p-1) o pour tout i dans {0,...,n}, 
%                                         pour tout j dans {1,...,p-1},
%              theta(i+1,j) est l'angle articulaire (A{j-1}_A_{j},A{j}_A_{j+1})
%               l'instant t_i=i/fe
%    *  fe : frquence d'acquisition
%    CES DEUX DONNEES CORRESPONDENT AU KINOGRAMME INITIAL
%    * meth : chane de caractre indiquant la mthode choisie
%           * 'i' : interpolation polynmiale
%           * 's' : interpolation par spline cubique (spline)
%           * 'p' : interpolation par Hermite cubique (pchip)
%    * q : entier suprieur  un gal au rapport frquence enrichie/frquence initiale
%  * Variables de sortie : 
%    CES DONNEES CORRESPONDENT AU KINOGRAMME ENRICHI
%     * thetan : tableau de type (nr+1,p-1) o pour tout i dans {0,...,nr}, 
%                                         pour tout j dans {1,...,p-1},
%              thetan(i+1,j) est l'angle articulaire (A{j-1}_A_{j},A{j}_A_{j+1})
%               l'instant t_i=i/fer
%     * dthetan : tableau de type (nr+1,p-1) o pour tout i dans {0,...,nr}, 
%                                         pour tout j dans {1,...,p-1},
%              dthetan(i+1,j) est la vitesse de l'angle articulaire (A{j-1}_A_{j},A{j}_A_{j+1})
%               l'instant t_i
%     * ddthetan : tableau de type (nr+1,p-1) o pour tout i dans {0,...,nr}, 
%                                         pour tout j dans {1,...,p-1},
%              ddthetan(i+1,j) est l'accalration de l'angle articulaire (A{j-1}_A_{j},A{j}_A_{j+1})
%               l'instant t_i
%
%
%
% ************ Fonctions auxiliaires utilises ************
%
%    diff_div_dist, eval_hornerder
%
%    ATTENTION : utilise la fonction fnder de la toobox matlab 
%    splines (C:\MATLAB6p1\toolbox\splines).
%    fnder.m n'est pas prsente dans la version 7 de matlab.
%    La fonction fnder.m est stocke dans ce rpertoire
%    et renomme OLDfnder.m 
%    A TESTER SOUS LES VERSIONS ULTERIEURES DE MATLAB.
%
% *********************************************************
%
% 2007 by          Jrme BASTIEN
%                  Universit Claude Bernard Lyon I, UFRSTAPS, Laboratoire CRIS, Villeurbanne
%                  E-Mail : jerome.bastien@univ-lyon1.fr

[np,p]=size(theta);
n=np-1;
temps=(0:n)/fe;
tempsn=(0:q*n)/(q*fe);
thetan=zeros(q*n+1,p);
dthetan=zeros(q*n+1,p);
ddthetan=zeros(q*n+1,p);
for j=1:p
    switch meth
        case 'i'
            D=diff_div_dist(temps,theta(:,j));
            [Z,Zp,Zpp]=eval_hornerder(tempsn,temps(1:end-1),D);
            thetan(:,j)=Z.';
            dthetan(:,j)=Zp.';
            ddthetan(:,j)=Zpp.';
        case 's'
            pp0=spline(temps,theta(:,j));
            for kk=1:2
                eval(['pp',int2str(kk),'=','OLDfnder(pp',int2str(kk-1),');']);    
            end
            thetan(:,j)=(ppval(pp0,tempsn)).';
            dthetan(:,j)=(ppval(pp1,tempsn)).';
            ddthetan(:,j)=(ppval(pp2,tempsn)).';
        case 'p'
            pp0=pchip(temps,theta(:,j));
            for kk=1:2
                eval(['pp',int2str(kk),'=','OLDfnder(pp',int2str(kk-1),');']);    
            end
            thetan(:,j)=(ppval(pp0,tempsn)).';
            dthetan(:,j)=(ppval(pp1,tempsn)).';
            ddthetan(:,j)=(ppval(pp2,tempsn)).';
    end
end