function [Z,Zp,Zpp]=eval_hornerder(T,C,D)
% 
%
% eval_horner : valuation vectorielle (et ventuellement 
% de ses deux drives) d'un polynme  partir de sa forme de Newton.
%
%
% *********************************************************
%
%  [Z,Zp,Zpp]=eval_hornerder(T,C,D)
%     L'valuation est faite par l'algorithme de Hrner usuel 
%     Elle permet de calculer :
%         p_n(T)=d_0+d_1(T-c_1)+d_2(T-c_1)(T-c_2)+...+d_n(T-c_1)...(T-c_n)
%         ainsi que p_n'(T) et p_n"(T)
%
%	variables d'entres : 
%     * T : contient le tableau (quelconque) ou symbolique des rels o est valu p_n
%     * C : contient les centres c_i, pour 1 <=i<=n
%     * D : contient les coefficients d_i, pour 0<=i<=n 	
%
%	variables de sortie
%     * Z : contient le tableau des images de T par p_n	
%     * Zp : contient ventuellement le tableau des images de T par p_n'
%     * Zpp : contient  ventuellement le tableau des images de T par p_n"	
%
%
% ************ Fonctions auxiliaires utilises ************
%
%       aucune
%
% *********************************************************


% Contrles d'entre
%
nout=nargout;
% test d'erreur
if ((nout<=0)|(nout>=4))
   error('Il faut entre 1 et 3 arguments de sortie');
end    
% nombre d'arguments
if nargin~=3
   error('nombre d''arguments de la fonction incorrect');
end
% taille des variables C et D
n=length(C);
np=length(D)-1;
if n~=np
   error('les deux tableaux n''ont pas la taille adquate');
end


% Corps d'algorithme
switch n
    case 0
      if isnumeric(T)
          Z=zeros(size(T));
          if (nout>=2)
             Zp=zeros(size(T)); 
          end
          if (nout==3)
             Zpp=zeros(size(T)); 
          end
      else
          Z=sym(zeros(size(T)));
          if (nout>=2)
             Zp=sym(zeros(size(T))); 
          end
          if (nout==3)
             Zpp=sym(zeros(size(T))); 
          end
      end
      Z(:)=D(1);
    case 1
       if isnumeric(T)
          Z=zeros(size(T));
          if (nout>=2)
             Zp=zeros(size(T)); 
          end
          if (nout==3)
             Zpp=zeros(size(T)); 
          end
       else
          Z=sym(zeros(size(T)));
          if (nout>=2)
             Zp=sym(zeros(size(T))); 
          end
          if (nout==3)
             Zpp=sym(zeros(size(T))); 
          end
      end
      Z(:)=D(1)+D(2)*(T-C(1));
      if (nout>=2)
          Zp(:)=D(2); 
      end
    otherwise
       if isnumeric(T)
          Auxip=zeros(size(T));
          if (nout>=2)
             Auxipp=zeros(size(T));
          end
          if (nout==3)
             Auxippp=zeros(size(T));
          end
       else
          Auxip=sym(zeros(size(T)));
          if (nout>=2)
             Auxipp=sym(zeros(size(T)));
          end
          if (nout==3)
             Auxippp=sym(zeros(size(T)));
          end
       end
       Auxip(:)=D(n+1);
       if (nout>=2)
          Auxipp(:)=D(n+1);
       end
       if (nout==3)
          Auxippp(:)=D(n+1);
       end
       for i=n-1:-1:2
          Auxip=D(i+1)+(T-C(i+1)).*Auxip;
          if (nout>=2)
             Auxipp=Auxip+(T-C(i)).*Auxipp;
          end
          if (nout==3)
             Auxippp=Auxipp+(T-C(i-1)).*Auxippp;
          end
       end
       Auxip=D(2)+(T-C(2)).*Auxip;
       if (nout>=2)
          Auxipp=Auxip+(T-C(1)).*Auxipp;
       end
       Auxip=D(1)+(T-C(1)).*Auxip;
       Z=Auxip;
       if (nout>=2)
          Zp=Auxipp;
       end
       if (nout==3)
          Zpp=2*Auxippp;
       end
end
