function [thetan,dthetan,ddthetan]=lissageenrichissementkino_angl(theta,fe,pfil,q)

% lissage, enrichissement et calcul des vitesses et des acclrations approches des angles theta d'un kinogramme
%
% *********************************************************
%  [thetan,dthetan,ddthetan]=lissageenrichissementkino_angl(theta,fe,pfil,q) :  
%
%  * Variables d'entre : 
%     * theta : tableau de type (n+1,p-1) o pour tout i dans {0,...,n}, 
%                                         pour tout j dans {1,...,p-1},
%              theta(i+1,j) est l'angle articulaire (A{j-1}_A_{j},A{j}_A_{j+1})
%               l'instant t_i=i/fe
%    *  fe : frquence d'acquisition
%    CES DEUX DONNEES CORRESPONDENT AU KINOGRAMME INITIAL
%    * pfil : paramtre dans [0,1] pour le lissage (pour la fonction csaps)
%    * q : entier suprieur  un gal au rapport frquence enrichie/frquence initiale
%  * Variables de sortie : 
%    CES DONNEES CORRESPONDENT AU KINOGRAMME ENRICHI
%     * thetan : tableau de type (nr+1,p-1) o pour tout i dans {0,...,nr}, 
%                                         pour tout j dans {1,...,p-1},
%              thetan(i+1,j) est l'angle articulaire (A{j-1}_A_{j},A{j}_A_{j+1})
%               l'instant t_i=i/fer
%     * dthetan : tableau de type (nr+1,p-1) o pour tout i dans {0,...,nr}, 
%                                         pour tout j dans {1,...,p-1},
%              dthetan(i+1,j) est la vitesse de l'angle articulaire (A{j-1}_A_{j},A{j}_A_{j+1})
%               l'instant t_i
%     * ddthetan : tableau de type (nr+1,p-1) o pour tout i dans {0,...,nr}, 
%                                         pour tout j dans {1,...,p-1},
%              ddthetan(i+1,j) est l'accalration de l'angle articulaire (A{j-1}_A_{j},A{j}_A_{j+1})
%               l'instant t_i
%
%
%
% ************ Fonctions auxiliaires utilises ************
%
%    ATTENTION : utilise les fonctions csaps et fnder, de la toobox matlab 
%    splines (C:\MATLAB6p1\toolbox\splines).
%    csaps.m et fnder.m ne sont pas prsentes dans la version 7 de matlab.
%    Les fonctions  csaps.m et fnder.m sont stockes dans ce rpertoire
%    et renommes OLDcsaps.m et OLDfnder.m
%    A TESTER SOUS LES VERSIONS ULTERIEURES DE MATLAB.
%
% *********************************************************
%
% 2007 by          Jrme BASTIEN
%                  Universit Claude Bernard Lyon I, UFRSTAPS, Laboratoire CRIS, Villeurbanne
%                  E-Mail : jerome.bastien@univ-lyon1.fr

[np,p]=size(theta);
n=np-1;
temps=(0:n)/fe;
tempsn=(0:q*n)/(q*fe);
thetan=zeros(q*n+1,p);
dthetan=zeros(q*n+1,p);
ddthetan=zeros(q*n+1,p);
for j=1:p
    pp0=OLDcsaps(temps,theta(:,j),pfil);
    for kk=1:2
        eval(['pp',int2str(kk),'=','OLDfnder(pp',int2str(kk-1),');']);    
    end
    thetan(:,j)=(ppval(pp0,tempsn)).';
    dthetan(:,j)=(ppval(pp1,tempsn)).';
    ddthetan(:,j)=(ppval(pp2,tempsn)).';
end