function tracekinovitkinoB(CX,CY,dXa,dYa,tracart,alphaa,indvit,nomfic,nomeps)

% trac des vitesses approches sur le kinogramme
%
% *********************************************************
%  tracekinovitkinoB(CX,CY,dXa,dYa,tracart,alphaa,indvit,nomfic,nomeps) : 
%  trace 
%  * le kinogramme en bleu
%  * ventuellement les trajectoires des articulations en rouge 
%  * les positions des articulations avec un rond rouge
%  * les vecteurs vitesse approches en vert pointill
%
%  * Variables d'entre : 
%     *  CX :  tableau de type (n+1,p) o pour tout i dans {0,...,n}, 
%                                         pour tout j dans {1,...,p},
%              CX(i+1,j) est l'abscisse de A_j  l'instant t_i=i/fe
%     *  CY :  tableau de type (n+1,p) o pour tout i dans {0,...,n}, 
%                                         pour tout j dans {1,...,p},
%              CY(i+1,j) est l'ordonne de A_j  l'instant t_i=i/fe
%     *  dXa :  tableau de type (n,p) o pour tout i dans {0,...,n}, 
%                                        pour tout j dans {1,...,p},
%               dXa(i+1,j) est l'abscisse de la vitesse aproche de A_j  l'instant
%               t_i
%     *  dYa :  tableau de type (n,p) o pour tout i dans {0,...,n}, 
%                                        pour tout j dans {1,...,p},
%               dXa(i+1,j) est l'ordonne de la vitesse aproche de A_j  l'instant
%               t_i
%    *   tracart : entier gal  0 (pas de trac des trajectoires des articulation) ou 1 (trac) 
%    *   alphaa : coefficient d'chelle pour la vitesse
%    *   indvit=indice d'articulation dont la vitesse n'est pas en pointill
%        si vide, toutes identiques
%  * Variables d'entre facultative (dans l'ordre)
%     *  nomfic : nom du fichier texte sans l'extension txt (pour le titre)
%     *  nomeps : nom du fichier de stockage de la figure eps (sans
%                    extension eps)
%
%
% ************ Fonctions auxiliaires utilises ************
%
%    aucune
%
% *********************************************************
%
% 2007 by          Jrme BASTIEN
%                  Universit Claude Bernard Lyon I, UFRSTAPS, Laboratoire CRIS, Villeurbanne
%                  E-Mail : jerome.bastien@univ-lyon1.fr

%CXm=(CX(2:end,:)+CX(1:end-1,:))/2;
%CYm=(CY(2:end,:)+CY(1:end-1,:))/2;
CXm=CX;
CYm=CY;
VitfinX=CXm+alphaa*dXa;
VitfinY=CYm+alphaa*dYa;
clf;
hold on;
axis equal;
if (tracart)
   plot(CXm,CYm,'r');
end
plot(CXm',CYm','b');
plot(CXm,CYm,'or');
[oubli,pm]=size(CXm);
if isempty(indvit)
    for i=1:pm
        plot(([CXm(:,i),VitfinX(:,i)])',([CYm(:,i),VitfinY(:,i)])','g:'); 
     end
else
    for i=1:indvit-1
        plot(([CXm(:,i),VitfinX(:,i)])',([CYm(:,i),VitfinY(:,i)])','g:'); 
     end
    for i=indvit
        plot(([CXm(:,i),VitfinX(:,i)])',([CYm(:,i),VitfinY(:,i)])','g'); 
    end
    for i=indvit+1:pm
        plot(([CXm(:,i),VitfinX(:,i)])',([CYm(:,i),VitfinY(:,i)])','g:'); 
    end
end
if nargin>=8
    title(['vitesse de ',nomfic,' Facteur d''chelle : ',num2str(1/alphaa)]);
end
if nargin==9
   eval(['print -depsc ',nomeps,'.eps;']); 
end
hold off;  