function  [fe,CXn,CYn,dXn,dYn,dn,ddXn,ddYn,ddn,l,theta,dis,dtheta,ddtheta,ecXY]=...
          traitekinogrammeB(meth,q,nomfic,tracart,alphaavit,indvit,alphaaacc,...
          indacc,nomavi,fevai,nomepskino,nomepsvit,nomepsacc,nomtemps,nomangle)

% lecture et enrichissement de donnees d'un kinogramme et traitement des coordonnes
%
% *********************************************************
%  [fe,CXn,CYn,dXan,dYan,dnan,ddXan,ddYan,ddnan,l,theta,dis,dtheta,ddtheta,ecXY]=...
%  traitekinogrammeB(meth,q,nomfic,tracart,alphaavit,indvit,alphaaacc,...
%  indacc,nomavi,fevai,nomepskino,nomepsvit,nomepsacc,nomtemps,nomangle) :
%
%  Lit le fichier de donnes texte (de type donneeskinogtapoint.txt) et 
%
% - enrichit le kinogramme
% - affiche les donnes spatiales et temporelles (dplacements, vitesses et acclration)
%   ventuellement angles
% - enregistre une animation si nomavi
% - stocke les fichiers eps si les noms correspondant sont prsents.
%
%  Variables d'entres : 
%    * meth : chane de caractre indiquant la mthode choisie
%           * 'i' : interpolation polynmiale
%           * 's' : interpolation par spline cubique (spline)
%           * 'p' : interpolation par Hermite cubique (pchip)
%    * q : entier suprieur  un gal au rapport frquence enrichie/frquence initiale
%    *   nomfic : nom du fichier texte sans l'extension txt
%    *   tracart : entier gal  0 (pas de trac des trajectoires des articulation) ou 1 (trac) 
%    *   alphaavit : coefficient d'chelle pour la vitesse
%    *   indvit=indice d'articulation dont la vitesse n'est pas en pointill
%        si vide, toutes identiques
%    *   alphaaacc : coefficient d'chelle pour l'acclration
%    *   indacc=indice d'articulation dont l'acclration n'est pas en pointill
%        si vide, toutes identiques
%  Variables d'entres optionneelles (dans l'ordre)
%     *  nomavi : nom du fichier de stockage de l'animation avi (sans
%                    extension)
%     *  fevai : frquence du nombre d'image pour l'animation avi
%     *  nomepskino : nom du fichier de stockage de la figure eps (sans
%                    extension eps) pour le kinogramme
%     *  nomepsvit : nom du fichier de stockage de la figure eps (sans
%                    extension eps) pour les vitesses (espace)
%     *  nomepsacc : nom du fichier de stockage de la figure eps (sans
%                    extension eps) pour les acclration (espace)
%     *  nomtemps : nom du fichier de stockage de la figure eps (sans
%                    extension eps) pour les donnes temporelles 
%     *  nomangle : nom du fichier de stockage de la figure eps (sans
%                    extension eps) pour les angles
%  * Variables de sortie : 
%    *  fe : frquence d'acquisition (non enrichie)
%    CES DONNEES CORRESPONDENT AU KINOGRAMME ENRICHI
%     *  CXn :  tableau de type (nr+1,p) o pour tout i dans {0,...,nr}, 
%                                          pour tout j dans {1,...,p},
%              CX(i+1,j) est l'abscisse de A_j  l'instant t_i=i/fer
%     *  CYn :  tableau de type (nr+1,p) o pour tout i dans {0,...,nr}, 
%                                          pour tout j dans {1,...,p},
%              CY(i+1,j) est l'ordonne de A_j  l'instant t_i=i/fer
%     *  dXn :  tableau de type (nr+1,p) o pour tout i dans {0,...,nr}, 
%                                           pour tout j dans {1,...,p},
%               dXn(i+1,j) est l'abscisse de la vitesse de A_j  l'instant
%               t_i=i/fer
%     *  dYn :  tableau de type (nr+1,p) o pour tout i dans {0,...,nr}, 
%                                           pour tout j dans {1,...,p},
%               dXn(i+1,j) est l'ordonne de la vitesse de A_j  l'instant
%               t_i=i/fer
%     *  dn :  tableau de type (nr+1,p) o pour tout i dans {0,...,nr}, 
%                                           pour tout j dans {1,...,p},
%               dn(i+1,j) est la norme de la vitesse de A_j  l'instant
%               t_i=i/fer
%     *  ddXn :  tableau de type (nr+1,p) o pour tout i dans {0,...,nr}, 
%                                           pour tout j dans {1,...,p},
%               ddXn(i+1,j) est l'abscisse de l'acclration de A_j  l'instant
%               t_i=i/fer
%     *  ddYn :  tableau de type (nr+1,p) o pour tout i dans {0,...,nr}, 
%                                           pour tout j dans {1,...,p},
%               ddYn(i+1,j) est l'ordonne de l'acclration de A_j  l'instant
%               t_i=i/fer
%     *  ddn :  tableau de type (nr+1,p) o pour tout i dans {0,...,nr}, 
%                                           pour tout j dans {1,...,p},
%               dnn(i+1,j) est la norme de l'acclration de A_j  l'instant
%               t_i=i/fer
%  Variables de sortie optionnelles :
%     *  l :  tableau de type (1,p-1) reprsentant les longueurs 
%             moyennes en temps
%     * theta : tableau de type (nr+1,p-1) o pour tout i dans {0,...,nr}, 
%                                         pour tout j dans {1,...,p-1},
%              theta(i+1,j) est l'angle articulaire (A{j-1}_A_{j},A{j}_A_{j+1})
%               l'instant t_i=i/fer
%     * dis :  tableau de type (1,p-1) reprsentant les dispersion des longueurs 
%              (dviation standart/moyenne)
%     * dtheta : tableau de type (nr+1,p-1) o pour tout i dans {0,...,nr}, 
%                                         pour tout j dans {1,...,p-1},
%              dtheta(i+1,j) est la vitesse de l'angle articulaire (A{j-1}_A_{j},A{j}_A_{j+1})
%               l'instant t_i
%     * ddtheta : tableau de type (nr+1,p-1) o pour tout i dans {0,...,nr}, 
%                                         pour tout j dans {1,...,p-1},
%              dtheta(i+1,j) est l'accalration de l'angle articulaire (A{j-1}_A_{j},A{j}_A_{j+1})
%               l'instant t_i
%     * ecXY : cart maximum entre les X, Y et les X et Y reconstitus  partir des angles

%
%
% ************ Fonctions auxiliaires utilises ************
%
%    ../lecture kinogramme/litfichierdonneskino
%    long_angle
%    calculapproch_vi_acc_ang
%    enrichissementkino
%    enrichissementkino_angl
%    reconst_angle_der
%    calculapproch_vi_acc
%    ../lecture kinogramme/tracekinogramme
%    tracekinovitkinoB
%    tracekinoacckinoB
%    tracecoordvitaccB
%    tracecoordvitacc_angB
% 
% *********************************************************
%
% 2007 by          Jrme BASTIEN
%                  Universit Claude Bernard Lyon I, UFRSTAPS, Laboratoire CRIS, Villeurbanne
%                  E-Mail : jerome.bastien@univ-lyon1.fr

[CX,CY,fe]=litfichierdonneskino(nomfic);
[dXa,dYa,dna,ddXa,ddYa,ddna]=calculapproch_vi_acc(CX,CY,fe);    
nout=nargout;
if (nout==15)
    [l,theta0,dis]=long_angle(CX,CY);
    [dtheta0,ddtheta0]=calculapproch_vi_acc_ang(theta0,fe);
    [CX1,CY1,dX1,dY1,dnaaa,ddX1,ddY1,ddnaaa]=enrichissementkino(CX(:,1),CY(:,1),fe,meth,q);  
    [theta,dtheta,ddtheta]=enrichissementkino_angl(theta0,fe,meth,q);
    [CXn,CYn,dXn,dYn,ddXn,ddYn]=reconst_angle_der(l,theta,CX1,CY1,dtheta,dX1,dY1,ddtheta,ddX1,ddY1);
    ecXY=max([max(max(abs(CX-CXn(1:q:end,:)))),max(max(abs(CY-CYn(1:q:end,:))))]);    
    dn=sqrt(dXn.^2+dYn.^2);
    ddn=sqrt(ddXn.^2+ddYn.^2);    
else    
    [CXn,CYn,dXn,dYn,dn,ddXn,ddYn,ddn]=enrichissementkino(CX,CY,fe,meth,q);    
end
switch nargin
    case 8
        tracekinogramme(CXn,CYn,tracart,nomfic);    
    case 10
        tracekinogramme(CXn,CYn,tracart,nomfic,nomavi,fevai);
    otherwise
        tracekinogramme(CXn,CYn,tracart,nomfic,nomavi,fevai,nomepskino);
end
disp('Appuyez sur une touche pour continuer');
pause;
if nargin>=11
    tracekinovitkinoB(CXn,CYn,dXn,dYn,tracart,alphaavit,indvit,nomfic,nomepsvit);
else    
    tracekinovitkinoB(CXn,CYn,dXn,dYn,tracart,alphaavit,indvit,nomfic);
end
disp('Appuyez sur une touche pour continuer');
pause;
if nargin>=12
    tracekinoacckinoB(CXn,CYn,ddXn,ddYn,tracart,alphaaacc,indacc,nomfic,nomepsacc);
else    
    tracekinoacckinoB(CXn,CYn,ddXn,ddYn,tracart,alphaaacc,indacc,nomfic);
end
disp('Appuyez sur une touche pour continuer');
pause;
if nargin>=13
     tracecoordvitaccB(fe,CX,CY,dXa,dYa,dna,ddXa,ddYa,ddna,...
                        q,CXn,CYn,dXn,dYn,dn,ddXn,ddYn,ddn,nomfic,nomtemps);
else    
     tracecoordvitaccB(fe,CX,CY,dXa,dYa,dna,ddXa,ddYa,ddna,...
                        q,CXn,CYn,dXn,dYn,dn,ddXn,ddYn,ddn,nomfic);
end
if (nout==15)
    disp('Appuyez sur une touche pour continuer');
    pause;
    if nargin>=15            
        tracecoordvitacc_angB(fe,theta0,dtheta0,ddtheta0,q,theta,dtheta,ddtheta,nomfic,nomangle);
    else
        tracecoordvitacc_angB(fe,theta0,dtheta0,ddtheta0,q,theta,dtheta,ddtheta,nomfic);
    end    
end